## Smart Lorentz Gauss


### What the package can do for you
This package provides functionalities to compute an n-dimensional mixed Lorentz-Gauss line shape, also called an n-dimensional Pseudo-Voigt function. Typically such functions occur in spectroscopic data originating from electro-magnetic radiation. The function can for example be used for fitting or deconvolution of such data, or for simulating (computing) spectra, i.e. as a superposition of several shapes with different parameters.


### The major API functionalities
 
- class `LorentzGauss`

This example constructs a LorentzGauss shape with the given height, center, width, and Gaussian fraction.

`LorentzGauss lg = new LorentzGauss.fromPars(height, [center], [width], [0.2]);`

This example would compute the value of the above shape value at position x.

`double val = lg.getValueAt(x]);`
      

#### Detailed API
Please view the detailed API documentation in the `API` reference of this package (sidebar at the right of this page).


### Using this package
You need Dart 2.0 or later.

Import the package using:
- `import 'package:smart_arrays_peaks/smart_arrays.dart_peaks';`

### Related packages

[`smart_arrays_base`: Basic functions for 1D and 2D arrays]( https://pub.dartlang.org/packages/smart_arrays_base)

[`smart_arrays_compress`: Compress 1D and 2D arrays to a smaller size]( https://pub.dartlang.org/packages/smart_arrays_compress)

[`smart_arrays_peaks`: Pick peaks in 1D and 2D arrays.]( https://pub.dartlang.org/packages/smart_arrays_peaks)

[`smart_signal_processing`: Fourier transform and more.]( https://pub.dartlang.org/packages/smart_signal_processing)

[`smart_dialogs`: Easy-to-use dialogs in Web applications]( https://pub.dartlang.org/packages/smart_dialogs)